@@ -9,18 +9,19 @@ OC.L10N.register(
     "Completed" : "完了",
     "Tasks" : "タスク",
     "The Tasks app for Nextcloud" : "Nextcloud用のタスクアプリ",
-    "Share with users or groups" : "ユーザーまたはグループと共有する",
-    "No users or groups" : "ユーザーまたはグループはありません",
-    "can edit" : "編集を許可",
-    "Unshare with {displayName}" : "{displayName}との共有を解除",
-    "Unable to delete the share." : "共有を解除できません。",
-    "Unable to change permissions." : "権限を変更できません。",
+    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal, … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "有効にすると、Nextcloudアプリのメニューに新しいタスクメニューが表示されます。 そこからタスクの追加や削除、タイトル、説明、開始日、期限を編集して重要なタスクとしてマークすることができます。 タスクはユーザー間で共有することができます。 タスクはCalDavを使って同期することができます。 各タスクリストはNextcloudのカレンダーにリンクされており、ローカルクライアント（Thunderbird、Evolution、KDE Kontact、iCalなど）と同期するには、クライアントのリモートカレンダーとしてカレンダーを追加します。 各カレンダーのダウンロードボタンを使って、タスクをICSファイルとしてダウンロードすることができます。",
     "Add List…" : "リストを追加…",
     "New List" : "新規リスト",
     "Cancel" : "キャンセル",
     "Save" : "保存",
     "The name \"{calendar}\" is already used." : "\"{calendar}\"の名称は既に使用されています。",
     "An empty name is not allowed." : "件名を入力してください。",
+    "Share with users or groups" : "ユーザーまたはグループと共有する",
+    "No users or groups" : "ユーザーまたはグループはありません",
+    "can edit" : "編集を許可",
+    "Unshare with {displayName}" : "{displayName}との共有を解除",
+    "Unable to delete the share." : "共有を解除できません。",
+    "Unable to change permissions." : "権限を変更できません。",
     "Edit" : "編集",
     "Copy private link" : "プライベートリンクをコピー",
     "Copied" : "コピーしました",
@@ -29,9 +30,12 @@ OC.L10N.register(
     "Delete" : "削除",
     "Unshare" : "共有を解除",
     "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "カレンダー\"{calendar}\"とカレンダーに対応するすべてのイベントとタスクが削除されます。",
+    "This will unshare the calendar \"{calendar}\"." : "カレンダー \"{calendar}\" の共有を解除します。",
     "Calendar link copied to clipboard." : "カレンダーリンクをクリップボードにコピー",
     "Calendar link could not be copied to clipboard." : "カレンダーリンクをクリップボードにコピーできませんでした。",
     "An error occurred, unable to delete the calendar." : "エラーが発生したため、カレンダーを削除できません。",
+    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["{countdown}秒後にカレンダーを削除します"],
+    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown}秒後にカレンダーの共有を解除します"],
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num}個のエンティティと共有"],
     "Default list" : "デフォルトリスト",
     "Visibility of Smart Collections" : "スマートコレクションの表示",
@@ -40,11 +44,13 @@ OC.L10N.register(
     "Automatic" : "自動",
     "Delete all completed tasks." : "全ての完了したタスクを削除",
     "Delete completed tasks." : "完了したタスクを削除",
+    "Deleted all completed tasks from calendar \"{calendar}\"." : "カレンダー \"{calendar}\" から完了したタスクをすべて削除しました。",
     "No errors" : "エラーはありません",
     "Open your browser console for more details" : "詳細はブラウザコンソールを開きます",
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} 個のタスクが削除できませんでした"],
     "Load all completed tasks." : "完了済みタスクを読み込み",
     "Change sort order" : "並び順を変更",
+    "Relevance" : "関連性",
     "Sort by completed state, due date, priority, start date and summary." : "完了状態、期日、優先順位、開始日、および要約で並べ替えます。",
     "Start date" : "開始日",
     "Sort by start date and summary." : "開始日および要約で並べ替えます。",
@@ -64,6 +70,12 @@ OC.L10N.register(
     "Sort by manual order." : "手動で並べ替えます。",
     "Task is completed" : "タスク完了",
     "{complete} % completed" : "{complete} %完了",
+    "Add subtask" : "サブタスクを追加",
+    "Show subtasks" : "サブタスクを表示",
+    "Hide subtasks" : "サブタスクを非表示",
+    "Show completed subtasks" : "完了したサブタスクを表示",
+    "Hide completed subtasks" : "完了したサブタスクを非表示",
+    "Delete task" : "タスクを削除",
     "[Yesterday]" : "[昨日]",
     "[Today]" : "[今日]",
     "[Tomorrow]" : "[明日]",
